@@ -41,6 +41,7 @@ generate_keybindings! {
   jump_to_namespace,
   describe_resource,
   resource_yaml,
+  decode_secret,
   jump_to_pods,
   jump_to_services,
   jump_to_nodes,
@@ -211,7 +212,13 @@ pub const DEFAULT_KEYBINDING: KeyBindings = KeyBindings {
   resource_yaml: KeyBinding {
     key: Key::Char('y'),
     alt: None,
-    desc: "Get Resource YAML",
+    desc: "Get resource YAML",
+    context: HContext::Overview,
+  },
+  decode_secret: KeyBinding {
+    key: Key::Char('x'),
+    alt: None,
+    desc: "Decode secret",
     context: HContext::Overview,
   },
   jump_to_pods: KeyBinding {
