@@ -11,7 +11,7 @@ use tokio::sync::Mutex;
 
 use crate::app::App;
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, Eq, PartialEq)]
 pub enum IoEvent {
   GetKubeConfig,
   GetNodes,
@@ -29,6 +29,7 @@ pub enum IoEvent {
   GetReplicationControllers,
   GetStorageClasses,
   GetRoles,
+  GetClusterRoles,
   GetMetrics,
   RefreshClient,
 }
@@ -162,6 +163,9 @@ impl<'a> Network<'a> {
       IoEvent::GetRoles => {
         self.get_roles().await;
       }
+      IoEvent::GetClusterRoles => {
+        self.get_cluster_roles().await;
+      }
     };
 
     let mut app = self.app.lock().await;
