@@ -20,7 +20,7 @@ use crate::{
   banner::BANNER,
 };
 
-pub fn draw_overview<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+pub fn draw_overview<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   if app.show_info_bar {
     let chunks = vertical_chunks(vec![Constraint::Length(9), Constraint::Min(10)], area);
     draw_status_block(f, app, chunks[0]);
@@ -30,47 +30,47 @@ pub fn draw_overview<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
   }
 }
 
-fn draw_status_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_status_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let chunks = horizontal_chunks(
     vec![
-      Constraint::Length(30),
+      Constraint::Length(35),
       Constraint::Min(10),
-      Constraint::Length(40),
       Constraint::Length(30),
+      Constraint::Length(32),
     ],
     area,
   );
 
-  draw_cli_version_block(f, app, chunks[0]);
+  draw_namespaces_block(f, app, chunks[0]);
   draw_context_info_block(f, app, chunks[1]);
-  draw_namespaces_block(f, app, chunks[2]);
+  draw_cli_version_block(f, app, chunks[2]);
   draw_logo_block(f, app, chunks[3])
 }
 
-fn draw_logo_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_logo_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   // Banner text with correct styling
   let text = format!(
-    "{}\nv{} with ♥ in Rust {}",
+    "{}\n v{} with ♥ in Rust {}",
     BANNER,
     env!("CARGO_PKG_VERSION"),
     nw_loading_indicator(app.is_loading)
   );
   let mut text = Text::from(text);
-  text.patch_style(style_logo());
+  text.patch_style(style_logo(app.light_theme));
 
   // Contains the banner
   let paragraph = Paragraph::new(text).block(Block::default().borders(Borders::ALL));
   f.render_widget(paragraph, area);
 }
 
-fn draw_cli_version_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
-  let block = layout_block_default("CLI Info");
+fn draw_cli_version_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let block = layout_block_default(" CLI Info ");
   if !app.data.clis.is_empty() {
     let rows = app.data.clis.iter().map(|s| {
       let style = if s.status {
-        style_primary()
+        style_primary(app.light_theme)
       } else {
-        style_failure()
+        style_failure(app.light_theme)
       };
       Row::new(vec![
         Cell::from(s.name.as_ref()),
@@ -84,11 +84,11 @@ fn draw_cli_version_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rec
       .widths(&[Constraint::Percentage(50), Constraint::Percentage(50)]);
     f.render_widget(table, area);
   } else {
-    loading(f, block, area, app.is_loading);
+    loading(f, block, area, app.is_loading, app.light_theme);
   }
 }
 
-fn draw_context_info_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_context_info_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let chunks = vertical_chunks_with_margin(
     vec![
       Constraint::Length(3),
@@ -99,7 +99,7 @@ fn draw_context_info_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
     1,
   );
 
-  let block = layout_block_default("Context Info (toggle <i>)");
+  let block = layout_block_default(" Context Info (toggle <i>) ");
 
   f.render_widget(block, area);
 
@@ -108,22 +108,22 @@ fn draw_context_info_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
       vec![
         Spans::from(vec![
           Span::styled("Context: ", style_default(app.light_theme)),
-          Span::styled(&active_context.name, style_primary()),
+          Span::styled(&active_context.name, style_primary(app.light_theme)),
         ]),
         Spans::from(vec![
           Span::styled("Cluster: ", style_default(app.light_theme)),
-          Span::styled(&active_context.cluster, style_primary()),
+          Span::styled(&active_context.cluster, style_primary(app.light_theme)),
         ]),
         Spans::from(vec![
           Span::styled("User: ", style_default(app.light_theme)),
-          Span::styled(&active_context.user, style_primary()),
+          Span::styled(&active_context.user, style_primary(app.light_theme)),
         ]),
       ]
     }
     None => {
       vec![Spans::from(Span::styled(
         "Context information not found",
-        style_failure(),
+        style_failure(app.light_theme),
       ))]
     }
   };
@@ -136,7 +136,7 @@ fn draw_context_info_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
 
   let cpu_gauge = LineGauge::default()
     .block(Block::default().title("CPU:"))
-    .gauge_style(style_primary())
+    .gauge_style(style_primary(app.light_theme))
     .line_set(get_gauge_style(app.enhanced_graphics))
     .ratio(limited_ratio)
     .label(Spans::from(format!("{:.0}%", ratio * 100.0)));
@@ -147,30 +147,30 @@ fn draw_context_info_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Re
 
   let mem_gauge = LineGauge::default()
     .block(Block::default().title("Memory:"))
-    .gauge_style(style_primary())
+    .gauge_style(style_primary(app.light_theme))
     .line_set(get_gauge_style(app.enhanced_graphics))
     .ratio(limited_ratio)
     .label(Spans::from(format!("{:.0}%", ratio * 100.0)));
   f.render_widget(mem_gauge, chunks[2]);
 }
 
-fn draw_namespaces_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect) {
+fn draw_namespaces_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
   let title = format!(
-    "Namespaces {} (all: {})",
+    " Namespaces {} (all: {}) ",
     DEFAULT_KEYBINDING.jump_to_namespace.key, DEFAULT_KEYBINDING.select_all_namespace.key
   );
   let mut block = layout_block_default(title.as_str());
 
   if app.get_current_route().active_block == ActiveBlock::Namespaces {
-    block = block.style(style_secondary())
+    block = block.style(style_secondary(app.light_theme))
   }
 
   if !app.data.namespaces.items.is_empty() {
     let rows = app.data.namespaces.items.iter().map(|s| {
       let style = if Some(s.name.clone()) == app.data.selected.ns {
-        style_secondary()
+        style_secondary(app.light_theme)
       } else {
-        style_primary()
+        style_primary(app.light_theme)
       };
       Row::new(vec![
         Cell::from(s.name.as_ref()),
@@ -184,11 +184,11 @@ fn draw_namespaces_block<B: Backend>(f: &mut Frame<B>, app: &mut App, area: Rect
       .block(block)
       .highlight_style(style_highlight())
       .highlight_symbol(HIGHLIGHT)
-      .widths(&[Constraint::Percentage(80), Constraint::Percentage(20)]);
+      .widths(&[Constraint::Length(22), Constraint::Length(6)]);
 
     f.render_stateful_widget(table, area, &mut app.data.namespaces.state);
   } else {
-    loading(f, block, area, app.is_loading);
+    loading(f, block, area, app.is_loading, app.light_theme);
   }
 }
 
