@@ -19,6 +19,8 @@ use crate::app::{models::StatefulTable, ActiveBlock, App};
 
 static DESCRIBE_AND_YAML_HINT: &str = "| describe <d> | yaml <y> ";
 static DESCRIBE_YAML_AND_ESC_HINT: &str = "| describe <d> | yaml <y> | back to menu <esc> ";
+static DESCRIBE_YAML_DECODE_AND_ESC_HINT: &str =
+  "| describe <d> | yaml <y> | decode <x> | back to menu <esc> ";
 static COPY_HINT: &str = "| copy <c>";
 static NODES_TITLE: &str = "Nodes";
 static PODS_TITLE: &str = "Pods";
@@ -34,6 +36,7 @@ static SECRETS_TITLE: &str = "Secrets";
 static RPL_CTRL_TITLE: &str = "ReplicationControllers";
 static STORAGE_CLASSES_LABEL: &str = "StorageClasses";
 static ROLES_TITLE: &str = "Roles";
+static CLUSTER_ROLES_TITLE: &str = "ClusterRoles";
 static DESCRIBE_ACTIVE: &str = "-> Describe ";
 static YAML_ACTIVE: &str = "-> YAML ";
 
@@ -84,6 +87,7 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
     ActiveBlock::RplCtrl => draw_replication_controllers_tab(block, f, app, area),
     ActiveBlock::StorageClasses => draw_storage_classes_tab(block, f, app, area),
     ActiveBlock::Roles => draw_roles_tab(block, f, app, area),
+    ActiveBlock::ClusterRoles => draw_cluster_roles_tab(block, f, app, area),
     ActiveBlock::Describe | ActiveBlock::Yaml => {
       let mut prev_route = app.get_prev_route();
       if prev_route.active_block == block {
@@ -95,6 +99,7 @@ fn draw_more<B: Backend>(block: ActiveBlock, f: &mut Frame<'_, B>, app: &mut App
         ActiveBlock::RplCtrl => draw_replication_controllers_tab(block, f, app, area),
         ActiveBlock::StorageClasses => draw_storage_classes_tab(block, f, app, area),
         ActiveBlock::Roles => draw_roles_tab(block, f, app, area),
+        ActiveBlock::ClusterRoles => draw_cluster_roles_tab(block, f, app, area),
         _ => { /* do nothing */ }
       }
     }
@@ -853,7 +858,7 @@ fn draw_secrets_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rec
     area,
     ResourceTableProps {
       title,
-      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      inline_help: DESCRIBE_YAML_DECODE_AND_ESC_HINT.into(),
       resource: &mut app.data.secrets,
       table_headers: vec!["Namespace", "Name", "Type", "Data", "Age"],
       column_widths: vec![
@@ -1057,6 +1062,54 @@ fn draw_roles_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect)
   );
 }
 
+fn draw_cluster_roles_tab<B: Backend>(
+  block: ActiveBlock,
+  f: &mut Frame<'_, B>,
+  app: &mut App,
+  area: Rect,
+) {
+  draw_resource_tab!(
+    CLUSTER_ROLES_TITLE,
+    block,
+    f,
+    app,
+    area,
+    draw_cluster_roles_tab,
+    draw_cluster_roles_block,
+    app.data.clusterroles
+  );
+}
+
+fn draw_cluster_roles_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
+  let title = get_resource_title(
+    app,
+    CLUSTER_ROLES_TITLE,
+    "",
+    app.data.clusterroles.items.len(),
+  );
+
+  draw_resource_block(
+    f,
+    area,
+    ResourceTableProps {
+      title,
+      inline_help: DESCRIBE_YAML_AND_ESC_HINT.into(),
+      resource: &mut app.data.clusterroles,
+      table_headers: vec!["Name", "Age"],
+      column_widths: vec![Constraint::Percentage(50), Constraint::Percentage(50)],
+    },
+    |c| {
+      Row::new(vec![
+        Cell::from(c.name.to_owned()),
+        Cell::from(c.age.to_owned()),
+      ])
+      .style(style_primary(app.light_theme))
+    },
+    app.light_theme,
+    app.is_loading,
+  );
+}
+
 /// common for all resources
 fn draw_describe_block<B: Backend>(
   f: &mut Frame<'_, B>,
